Fix a typo on the Documentation web page.
[paraslash.git] / error.h
diff --git a/error.h b/error.h
index 469b85be0ebd40dc53ab7a9ba93c061b80fe4d62..5f27f1c9149e5648b0a2ff245956a0d4db8af66e 100644 (file)
--- a/error.h
+++ b/error.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2007 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 2006-2008 Andre Noll <maan@systemlinux.org>
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
@@ -27,9 +27,14 @@ DEFINE_ERRLIST_OBJECT_ENUM;
 #define AFH_COMMON_ERRORS
 #define RBTREE_ERRORS
 #define RECV_ERRORS
+#define SEND_COMMON_ERRORS
 
 extern const char **para_errlist[];
 
+#define ACL_ERRORS \
+       PARA_ERROR(ACL_PERM, "access denied by acl"), \
+
+
 #define FSCK_ERRORS \
        PARA_ERROR(FSCK_SYNTAX, "fsck syntax error"), \
        PARA_ERROR(RANGE_VIOLATION, "range violation detected, very bad"), \
@@ -55,7 +60,6 @@ extern const char **para_errlist[];
        PARA_ERROR(ALREADY_MAPPED, "file already mapped"), \
        PARA_ERROR(BAD_SIZE, "invalid size specified"), \
        PARA_ERROR(TRUNC, "failed to truncate file"), \
-       PARA_ERROR(UNLINK, "failed to remove file"), \
        PARA_ERROR(BAD_TABLE, "table not open"), \
        PARA_ERROR(BAD_TABLE_DESC, "invalid table description"), \
        PARA_ERROR(RB_KEY_EXISTS, "key already exists in rbtree"), \
@@ -64,8 +68,6 @@ extern const char **para_errlist[];
        PARA_ERROR(INDEX_CORRUPTION, "index corruption detected"), \
        PARA_ERROR(INVALID_OBJECT, "reference to invalid object"), \
        PARA_ERROR(STAT, "can not stat file"), \
-       PARA_ERROR(FSTAT, "fstat error"), \
-       PARA_ERROR(RENAME, "rename failed"), \
        PARA_ERROR(WRITE, "write error"), \
        PARA_ERROR(LSEEK, "lseek error"), \
        PARA_ERROR(BUSY, "table is busy"), \
@@ -91,7 +93,6 @@ extern const char **para_errlist[];
 #define MOOD_ERRORS \
        PARA_ERROR(MOOD_SYNTAX, "mood syntax error"), \
        PARA_ERROR(NO_MOOD, "no mood available"), \
-       PARA_ERROR(MOOD_LOADED, "mood loaded"), \
        PARA_ERROR(NOT_ADMISSIBLE, "file is not admissible"), \
 
 
@@ -107,7 +108,6 @@ extern const char **para_errlist[];
 
 
 #define PLAYLIST_ERRORS \
-       PARA_ERROR(NO_PLAYLIST, "no valid playlist found"), \
        PARA_ERROR(PLAYLIST_LOADED, ""), /* not really an error */ \
        PARA_ERROR(PATH_FOUND, ""), /* not really an error */ \
        PARA_ERROR(PLAYLIST_EMPTY, "attempted to load empty playlist"), \
@@ -171,7 +171,6 @@ extern const char **para_errlist[];
 
 
 #define NET_ERRORS \
-       PARA_ERROR(CONNECT, "connect error"), \
        PARA_ERROR(NAME_TOO_LONG, "name too long for struct sockaddr_un"), \
        PARA_ERROR(ADDRESS_LOOKUP, "address lookup / socket creation failed"), \
        PARA_ERROR(CHMOD, "failed to set socket mode"), \
@@ -197,8 +196,6 @@ extern const char **para_errlist[];
 #define RECV_COMMON_ERRORS \
        PARA_ERROR(RECV_SYNTAX, "recv syntax error"), \
        PARA_ERROR(RECV_EOF, "end of file"), \
-       PARA_ERROR(RECV_CONNECT, "connection failed"), \
-
 
 
 #define AUDIOD_ERRORS \
@@ -325,13 +322,12 @@ extern const char **para_errlist[];
 
 #define HTTP_SEND_ERRORS \
        PARA_ERROR(WRITE_OK, "can not check whether fd is writable"), \
-       PARA_ERROR(SEND_QUEUED_CHUNK, "failed to send queued chunk"), \
+       PARA_ERROR(MAX_CLIENTS, "maximal number of clients exceeded"), \
 
 
 #define COMMAND_ERRORS \
        PARA_ERROR(COMMAND_SYNTAX, "syntax error in command"), \
        PARA_ERROR(AUTH, "did not receive auth request"), \
-       PARA_ERROR(BAD_SELECTOR, "no such audio file selector"), \
        PARA_ERROR(NO_AUDIO_FILE, "no audio file"), \
        PARA_ERROR(BAD_CMD, "invalid command"), \
        PARA_ERROR(PERM, "permission denied"), \
@@ -350,23 +346,15 @@ extern const char **para_errlist[];
        PARA_ERROR(SHM_DETACH, "can not detach shared memory area"), \
 
 
-#define DCCP_ERRORS \
-       PARA_ERROR(DCCP_SOCKET, "can not create dccp socket"), \
-
-
 #define DCCP_RECV_ERRORS \
        PARA_ERROR(DCCP_OVERRUN, "dccp output buffer buffer overrun"), \
 
 
 #define DCCP_SEND_ERRORS \
-       PARA_ERROR(DCCP_WRITE, "dccp write error"), \
 
 
 #define FD_ERRORS \
        PARA_ERROR(FGETS, "fgets error"), \
-       PARA_ERROR(CHDIR, "failed to change directory"), \
-       PARA_ERROR(OPEN, "failed to open file"), \
-       PARA_ERROR(CHDIR_PERM, "insufficient permissions to chdir"), \
        PARA_ERROR(EMPTY, "file empty"), \
        PARA_ERROR(MMAP, "mmap error"), \
        PARA_ERROR(MUNMAP, "munmap failed"), \
@@ -462,27 +450,48 @@ extern const char **para_errlist[];
  */
 #define ERRNUM_TO_INDEX(num) (((1 << SS_SHIFT) - 1) & (num))
 
+/**
+ * This bit indicates whether a number is considered a system error number
+ * If yes, the system errno is just the result of clearing this bit from
+ * the given number.
+ */
 #define SYSTEM_ERROR_BIT 30
 
+/** Check whether the system error bit is set. */
 #define IS_SYSTEM_ERROR(num) (!!((num) & (1 << SYSTEM_ERROR_BIT)))
 
+/** Set the system error bit for the given number. */
 #define ERRNO_TO_PARA_ERROR(num) ((num) | (1 << SYSTEM_ERROR_BIT))
 
-static inline int is_errno(int val, int _errno)
+/** Check whether a given number is a system error number.
+ *
+ * \param num The value to be checked.
+ * \param _errno The system error number.
+ *
+ * \return True if \a num is paraslash's representation of the system
+ * error identified by \a _errno.
+ */
+_static_inline_ int is_errno(int num, int _errno)
 {
-       assert(val > 0 && _errno > 0);
-       return ERRNO_TO_PARA_ERROR(_errno) == val;
+       assert(num > 0 && _errno > 0);
+       return ERRNO_TO_PARA_ERROR(_errno) == num;
 }
 
 /**
  * Paraslash's version of strerror(3).
  *
* Expands to the error text of \a num (a string constant).
  */
-#define PARA_STRERROR(num) IS_SYSTEM_ERROR(num)? \
-       strerror((num) & ((1 << SYSTEM_ERROR_BIT) - 1)) : \
-       para_errlist[ERRNUM_TO_SS(num)] [ERRNUM_TO_INDEX(num)]
-
+_static_inline_ const char *para_strerror(int num)
+{
+       assert(num > 0);
+       if (IS_SYSTEM_ERROR(num))
+               return strerror((num) & ((1 << SYSTEM_ERROR_BIT) - 1));
+       else
+               return para_errlist[ERRNUM_TO_SS(num)][ERRNUM_TO_INDEX(num)];
+}
 /**
  * Define the error list for one subsystem.
  #
@@ -462,27 +450,48 @@ extern const char **para_errlist[];
  * Paraslash's version of strerror(3).
  *
- * Expands to the error text of \a num (a string constant).
+ * \param num The error number.
+ *
+ * \return The error text of \a num.
  */